#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2011 <Davide Vescovini> <davide.vescovini@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
# A script to dump the contents of a Microsoft Access Database.
# It depends upon the mdbtools suite:  http://sourceforge.net/projects/mdbtools/

####################################################
# Importazione dei moduli
####################################################
 
import os
import sys
import subprocess # the subprocess module was introduced in python v 2.4
import csv
import datetime
from string import ascii_uppercase, digits
from preventares import preventa_lib
################################################################################
# Assegnazione COSTANTI
################################################################################
NOME_ARCHIVIO = "IMPIANTI ELETTRICI E SPECIALI"
PATH = os.getcwd()
FILE_ELETTRO = os.path.join(PATH, "ELETTRO.csv")
FILE_BLA_BLA = os.path.join(PATH, "BLA_BLA.csv")
FILE_LISTINO = os.path.join(PATH, "Listino.csv")
FILE_DATI_GENERALI = os.path.join(PATH, "GENERALE.csv")
FILE_PREVENTIVO = os.path.join(PATH, "PREVENTIVO.csv")
NOME_CAPITOLI = {"A": "Cavi",
                 "B": "Quadri e Carpenterie",
                 "C": "Apparecchi per Quadri Elettrici",
                 "D": "Apparecchi di Installazione",
                 "E": "Tubi e Canali",
                 "F": "Materiali per Messa a Terra",
                 "G": "Apparecchi Audio e Video",
                 "H": "Apparecchi per Impianti Televisivi",
                 "I": "Corpi Illuminanti",
                 "J": "Capitolo J",
                 "K": "Capitolo K",
                 "L": "Illuminazione di Emergenza",
                 "M": "Blindosbarre",
                 "N": "Impianti per Tecnologici",
                 "O": "Cabine e Impianti MT",
                 "P": "Impianti di Allarme",
                 "Q": "Capitolo Q",
                 "R": "Apparecchi Vari",
                 "S": "Impianti Antideflagranti Ex",
                 "T": "Capitolo T",
                 "U": "Capitolo U",
                 "W": "Capitolo W",
                 "X": "Opere Civili",
                 "Y": "Oneri di Legge",
                 "Z": "Opere Provvisionali"}
################################################################################
# Esecuzione del DUMP (export csv) di tutte le tavole del db mdb
################################################################################
def dump_mdb (DATABASE):
    # Get the list of table names with "mdb-tables"
    try:
        table_names = subprocess.Popen(["mdb-tables", "-1", DATABASE], stdout=subprocess.PIPE).communicate()[0]
    except OSError:
        raise OSError("Programma 'mdb-tables' del pacchetto 'mdb-tools' mancante")
        return
    tables = table_names.split('\n')
    # Dump each table as a CSV file using "mdb-export", converting " " in table names to "_" for the CSV filenames.
    filename_list = list()
    for table in tables:
        if table != '':
            filename = table.replace(" ","_") + ".csv"
            filename_list.append(filename)
            file = open(filename, 'w')
            print("Dumping " + table)
            contents = subprocess.Popen(["mdb-export", DATABASE, table], stdout=subprocess.PIPE).communicate()[0]
            file.write(contents)
            file.close()
    return filename_list

################################################################################
# Importazione di un ARCHIVIO da file CSV
################################################################################
def import_archivio(database_mdb, file_archivio):
    """"""
    ###############################################
    # estrae i file CSV dal database mdb
    ############################################
    filename_list = dump_mdb (database_mdb)
    ############################################
    # crea un nuovo file database
    ############################################
    preventivo = preventa_lib.Preventivo(file_archivio)
    # ottiene l'oggetto database
    database = preventivo.get_database()
    ############################################
    # crea i Capitoli nel database
    ############################################
    print("Creazione dei capitoli nel Database")
    preventivo.update_dati_generali (nome=None, 
                                    redattore="Studio Vescovini Associato", 
                                    ricarico=1.3, manodopera=28)
    preventivo.insert_capitoli_categorie("Supercapitolo", NOME_ARCHIVIO)
    for nome in NOME_CAPITOLI.values():
        preventivo.insert_capitoli_categorie("Capitolo", nome)
    for lettera in ascii_uppercase+digits:
        preventivo.insert_capitoli_categorie("Capitolo", lettera)
    ###############################################
    # BLA
    ###############################################
    print("Lettura del file csv %s" % FILE_BLA_BLA)
    # CODICE,VOCE,COST_MAT_,TEMP,QUANTITA,RIC,M_D_,PREZZO,QUAN1,DESC_VOCE,cod_str,ID
    # legge il file csv e crea un oggetto iterabile
    fbla = csv.reader(open(FILE_BLA_BLA, 'rb'))
    # per ogni articolo del file csv crea un articolo della lib preventa
    n=0
    lista_articoli = list()
    for line in fbla:
        n += 1
        (CODICE,VOCE,COST_MAT_,TEMP,QUANTITA,RIC,M_D_,PREZZO,QUAN1,DESC_VOCE,
         cod_str,ID) = line
        # cra l'articolo da inserire in lista
        articolo = preventa_lib.ArticoloComputo(database, 
                   1, 1, 0,
                   0, 0, 0, 
                   tariffa = CODICE+DESC_VOCE, 
                   codice=None, #int(ID), 
                   descrizione_codice=None,  
                   descrizione_voce=VOCE, 
                   descrizione_estesa=None, 
                   unita_misura=None, 
                   quantita=0,
                   ricarico=__floatconvert(RIC),
                   tempo_inst=__floatconvert(TEMP),
                   costo_materiali=__floatconvert(COST_MAT_), 
                   prezzo_unitario=None, 
                   sicurezza= None,
                   cod_listino=None, 
                   note=cod_str,
                   data= None)
        articolo.nome_supercapitolo = NOME_ARCHIVIO
        articolo.nome_capitolo = NOME_CAPITOLI.get(CODICE[:1], CODICE[:1].upper())
        articolo.nome_subcapitolo = str()
        lista_articoli.append(articolo)
    ###############################################
    # ELETTRO
    ###############################################
    print("Lettura del file csv %s" % FILE_ELETTRO)
    #CODICE,COD_STR,NOME,PRIMO,DATA,UN_MIS,TOT_DESC,MARCA,TIPO,CODICE_USL,Edita
    # legge il file csv e crea un oggetto iterabile
    felettro = csv.reader(open(FILE_ELETTRO, 'rb'))
    for line in felettro:
        (CODICE,COD_STR,NOME,PRIMO,DATA,UN_MIS,TOT_DESC,MARCA,
        TIPO,CODICE_USL,Edita) = line
        for articolo in lista_articoli:
            if articolo.tariffa[:4] == CODICE:
                articolo.descrizione_codice = NOME
                articolo.descrizione_estesa = Edita
                articolo.unita_misura = str(UN_MIS)
                articolo.data = DATA
    ###############################################
    # LISTINO
    ###############################################
    print("Lettura del file csv %s" % FILE_LISTINO)
    #CODICE,DESC_VOCE,LISTINO,SCONTO,ACCESSORI,PREZZO,QUAN1,ARTICOLO,DESCRIZIONE,ID
    lista_listino = list()
    # legge il file csv e crea un oggetto iterabile
    flistino = csv.reader(open(FILE_LISTINO, 'rb'))
    for line in flistino:
        (CODICE,DESC_VOCE,LISTINO,SCONTO,ACCESSORI,PREZZO,QUAN1,ARTICOLO,
        DESCRIZIONE,ID) = line
        # ricostruisce il codice metel
        if len(ARTICOLO) < 16:
            n_spazi = 16 - len(ARTICOLO)
            ARTICOLO += ' '* n_spazi 
        # assegna i campi all'articolo
        articolo = preventa_lib.ArticoloListino(database, 
                   tariffa= CODICE+DESC_VOCE, 
                   codice= LISTINO + ARTICOLO + "EUR", 
                   descrizione_codice= DESCRIZIONE, 
                   unita_misura= "N", 
                   quantita= __floatconvert(QUAN1), 
                   prezzo_unitario= __floatconvert(PREZZO), 
                   accessori=__floatconvert(ACCESSORI), 
                   sconto= __floatconvert(SCONTO),
                   nr=None, #int(ID), 
                   note=None)
        lista_listino.append(articolo)
    ###############################################
    # inserisce gli articoli nel database
    ###############################################
    print("Importazione degli articoli nel Database")
    i=0
    tot = len(lista_articoli)
    for articolo in lista_articoli:
        i+=1
        print "Articolo %d/%d" % (i,tot)
        try:
            preventivo.insert_articoli_from_archivio_epu (True, articolo)
        except:
            print "Errore importazione articolo %s: %s" % (articolo.tariffa, str(articolo))
    ###############################################
    # inserisce dei Listini nel database
    ###############################################
    print("Importazione degli elementi di Listino nel Database")
    preventivo.insert_articoli_listino (None, *lista_listino)
    # salva e chiude il database
    preventivo.save_database()
    preventivo.connection_shutdown()
    ###############################################
    # rimuove i file csv letti
    ###############################################
    print("Eliminazione dei file csv")
    os.remove(FILE_ELETTRO)
    os.remove(FILE_BLA_BLA)
    os.remove(FILE_LISTINO)
    os.remove('Scorta.csv')
    os.remove('prova.csv')
    os.remove('descrizio.csv')
    return True

################################################################################
# Importazione di un PREVENTIVO da file CSV
################################################################################

def import_preventivo(database_mdb, file_preventivo, 
                      file_csv_dg=None, file_csv_prev=None, 
                      file_csv_listino=None ):
    """"""
    if file_csv_dg is None:
        file_csv_dg = FILE_DATI_GENERALI
    if file_csv_prev is None:
        file_csv_prev = FILE_PREVENTIVO
    if file_csv_listino is None:
        file_csv_listino = FILE_LISTINO
    ###############################################
    # estrae i file CSV dal database mdb
    ###############################################
    filename_list = dump_mdb (database_mdb)
    ###############################################
    # crea un nuovo file database
    ###############################################
    preventivo = preventa_lib.Preventivo(file_preventivo)
    # ottiene l'oggetto database
    database = preventivo.get_database()
    # importa e inserisce i dati generali del preventivo
    diz_cap = __import_dati_generali(file_csv_dg, preventivo)
    # legge il file csv e crea un oggetto iterabile
    fprev = csv.reader(open(file_csv_prev, 'rb'))
    # per ogni articolo del file csv crea un articolo della lib preventa
    n=0
    lista_articoli = list()
    for art in fprev:
        n += 1
        (DESC_VOCE,UN_MIS,QUAN1,COST_MAT,TEMP,RIC,PREZ1, PARZIALI,
         N_ORDINE,TESTATA,EDITA,SUP_CAT_N,CAT_CAT_N,SUB_CAT_N,SUP_CAT_T,
         CAT_CAT_T,SUB_CAT_T,N_FILE,N_AVANZAMENTO,IVA,SCONTO,
         COSTO_SICUREZZA,PERCENTUALE_SICUREZZA,NOME,CODICE,VOCE) = art
        supercapitolo = 1
        capitolo = diz_cap.keys().index(CODICE[:1])
        subcapitolo = 0
        # assegna i campi all'articolo
        if n>1:
            articolo = preventa_lib.ArticoloComputo(database, 
                   supercapitolo, capitolo, subcapitolo,
                   __intconvert(SUP_CAT_N),
                   __intconvert(CAT_CAT_N),
                   __intconvert(SUB_CAT_N), 
                   tariffa = CODICE+DESC_VOCE, 
                   codice=None, descrizione_codice=NOME,  
                   descrizione_voce=VOCE, descrizione_estesa=EDITA, 
                   unita_misura=UN_MIS, 
                   quantita=__floatconvert(QUAN1),
                   ricarico=__floatconvert(RIC), 
                   tempo_inst=__floatconvert(TEMP),
                   costo_materiali=__floatconvert(COST_MAT), 
                   prezzo_unitario=None, 
                   sicurezza=__floatconvert(COSTO_SICUREZZA))
            articolo.nome_supercategoria = SUP_CAT_T
            articolo.nome_categoria = CAT_CAT_T
            articolo.nome_subcategoria = SUB_CAT_T
            articolo.nome_supercapitolo = NOME_ARCHIVIO
            articolo.nome_capitolo = diz_cap[CODICE[:1]]
            articolo.nome_subcapitolo = str()#TODO
            lista_articoli.append(articolo)
    # inserisce gli articoli nel database
    preventivo.insert_articoli_from_archivio_computo(*lista_articoli)
    # importa e inserisce gli articoli di listino
    __import_listino(file_csv_listino, preventivo)
    #############################
    # salva e chiude il database
    #############################
    preventivo.save_database()
    preventivo.connection_shutdown()
    ###############################################
    # rimuove i file csv letti
    ###############################################
    print("Eliminazione dei file csv")
    os.remove(file_csv_dg)
    os.remove(file_csv_prev)
    os.remove(file_csv_listino)
    os.remove('EPU.csv')
    return True

def __import_dati_generali(file_csv, preventivo):
    """"""
    n=0
    # dizionario capitoli
    diz_cap = dict()
    # ottiene l'oggetto database
    database = preventivo.get_database()
    # legge il file csv e crea una lista ed elimina la prima riga
    fdg = csv.reader(open(file_csv, 'rb'))
    # per ogni articolo del file csv crea un articolo della lib preventa
    for art in fdg:
        n += 1
        (NOME_DEL_FILE,TESTA,GENERALE,RIC,TEMP,M_D_,NomeTesta,
         IndirizzoTesta,CittaTesta,TelefonoTesta,ScortaTesta,
         Coda,ScortaCoda,N_Max_Contabilita,LAVORI,IMPRESA,
         COMUNE,DISPOSIZIONE,SUPERCAPITOLO,CAPITOLO,SUBCAPITOLO) = art
        # aggiorna i dati generali
        preventivo.update_dati_generali (nome=TESTA, 
                       cliente=None, 
                       redattore=NomeTesta, 
                       ricarico=__floatconvert(RIC),
                       manodopera=__floatconvert(M_D_), 
                       sicurezza=None, 
                       indirizzo=None, 
                       comune=COMUNE, 
                       provincia=None, 
                       valuta='Euro')
        # crea un dizionario dei CAPITOLI
        sup_list = SUPERCAPITOLO.split("|")
        cap_list = CAPITOLO.split("|")
        ab="ABCDEFGHIJKLMNOPQRSTUVWXZ"
        n_l=0
        for cap in cap_list:
            diz_cap[ab[n_l]] = cap
            n_l+=1
        for d in digits:
            diz_cap[d] = ''
        sub_list = SUBCAPITOLO.split("|")
    return diz_cap


def __import_listino(file_csv, preventivo):
    """"""
    n=0
    lista_listino = list()
    # ottiene l'oggetto database
    database = preventivo.get_database()
    # legge il file csv e crea una lista ed elimina la prima riga
    flist = csv.reader(open(file_csv, 'rb'))
    # per ogni articolo del file csv crea un articolo della lib preventa
    for art in flist:
        n += 1
        (DESC_VOCE,LISTINO,SCONTO,ACCESSORI,PREZZO,QUAN1,ARTICOLO,
        DESCRIZIONE,CODICE) = art
        # ricostruisce il codice metel
        if len(ARTICOLO) < 16:
            n_spazi = 16 - len(ARTICOLO)
            ARTICOLO += ' '* n_spazi
        # assegna i campi all'articolo
        if n>1:
            articolo = preventa_lib.ArticoloListino(database, 
                       tariffa= CODICE+DESC_VOCE, 
                       codice= LISTINO+ARTICOLO+"EUR", 
                       descrizione_codice= DESCRIZIONE, 
                       unita_misura= "N.", 
                       quantita= float(QUAN1), 
                       prezzo_unitario= float(PREZZO), 
                       accessori=float(ACCESSORI)/100*float(PREZZO), 
                       sconto= float(SCONTO),
                       nr=None, 
                       note=None)
            lista_listino.append(articolo)
    # inserisce gli articoli nel database
    result = preventivo.insert_articoli_listino (None, *lista_listino)
    return preventivo


################################################################################
# Importazione di un PREVENTIVO mdb formato 'Tariffario ANALIST'
################################################################################
def import_preventivo_mdb_ANALIST(database_mdb):
    """Importa articoli .mdb """
    ###############################################
    # estrae i file CSV dal database mdb
    ############################################
    filename_list = dump_mdb (database_mdb)
    FILE_PREZZI = "Prezzi.csv"
    FILE_TARIFFE = "Tariffe.csv"
    FILE_TARIFFARI = "Tariffari.csv"
    FILE_UM = "UniMis.csv"
    ###############################################
    NOME_FILE_DB = database_mdb.replace(".", "_") + ".db"
    preventivo = preventa_lib.Preventivo(NOME_FILE_DB)
    # ottiene l'oggetto database
    database = preventivo.get_database()
    # legge il file csv e crea oggetti iterabili
    fprezzi = csv.reader(open(FILE_PREZZI, 'rb'))
    ftariffe = csv.reader(open(FILE_TARIFFE, 'rb'))
    ftariffari = csv.reader(open(FILE_TARIFFARI, 'rb'))
    funimis = csv.reader(open(FILE_UM, 'rb'))
    # legge il nome dei tariffari
    diz_nomi = dict()
    for line in ftariffari:
        ID, Descrizione_Completa, Separatore, Descrizione = line
        diz_nomi[ID] = Descrizione_Completa
    # imposta e salva il nome dell'archivio
    nome_archivio = diz_nomi.get(1, NOME_FILE_DB)
    preventivo.update_dati_generali (nome=nome_archivio, cliente='', 
                                     redattore='', ricarico=1, 
                                     manodopera=None, sicurezza=0,  
                                     indirizzo='', comune='', 
                                     provincia='', valuta='euro')
    # crea il dizionario delle unita di misura
    diz_um = dict()
    for line in funimis:
        ID,Descrizione,Descrizione_compl = line
        diz_um[ID] = Descrizione
    # crea il dizionario dei prezzi
    diz_prezzi = dict()
    for line in fprezzi:
        ID,ID_Listino,ID_Tariffa,Sovrapprezzo,Data,Prezzo = line
        diz_prezzi[ID_Tariffa] = (Data,__floatconvert(Prezzo))
    # valori di default
    supercapitolo, capitolo, subcapitolo = (0,0,0)
    supercategoria, categoria, subcategoria = (0,0,0)
    nome_supercapitolo, nome_capitolo,  nome_subcapitolo = ('', '', '')
    # crea il dizionario dei nomi delle tariffe
    diz_nomi_tariffe = dict()
    lista_articoli = list()
    for line in ftariffe:
        (ID,ID_Tariffario,ID_TariffaPadre,Codice,Codice_Completo,ID_UniMis,
        Ricarico,Descrizione,Descrizione_Ridotta,Descrizione_Estesa,SubTariffa,
        IsVoceElementare,Articolo,bAnalisi,dUtile,dSpese,dSicurezza,
        dQtaProd,dImpAnalisi) = line
        # crea un dizionario delle 
        diz_nomi_tariffe[ID] = Descrizione
        # se la voce non è un prezzo elementare diventa una categoria
        if IsVoceElementare == "0":
            if ID_TariffaPadre == str():
                nome_supercapitolo = Descrizione_Estesa
            elif ID_TariffaPadre != str():
                nome_capitolo = diz_nomi_tariffe.get(ID_TariffaPadre, Descrizione_Estesa)
        # se la voce è elementare crea l'articolo
        elif IsVoceElementare == "1":
            articolo = preventa_lib.ArticoloComputo(database, 
                   supercapitolo, capitolo, subcapitolo,
                   supercategoria, categoria, subcategoria, 
                   tariffa = Codice_Completo, 
                   codice=ID, 
                   descrizione_codice=Descrizione,  
                   descrizione_voce=Descrizione_Ridotta, 
                   descrizione_estesa=Descrizione_Estesa, 
                   unita_misura=diz_um.get(ID_UniMis, ""), 
                   quantita= dQtaProd,
                   ricarico= 1 + (__floatconvert(Ricarico)/100),
                   tempo_inst= 0,
                   costo_materiali= diz_prezzi.get(ID_Tariffario, ("",0))[1],
                   prezzo_unitario=None, 
                   sicurezza= 0, 
                   data= diz_prezzi.get(ID_Tariffario, ("",0))[0])
            articolo.nome_supercapitolo = nome_supercapitolo
            articolo.nome_capitolo = nome_capitolo
            articolo.nome_subcapitolo = nome_subcapitolo
            lista_articoli.append(articolo)
            print "Importazione articolo: %s" % articolo.tariffa
        # negli altri casi stampa un messaggio di errore
        else:
            print "Errore, articolo: %s non importato" % Codice_Completo
    # inserisce gli articoli nel database
    nr = len(lista_articoli)
    print("Archiviazione di %d articoli nel database, attendere..." % nr)
    preventivo.insert_articoli_from_archivio_epu (True, *lista_articoli)
    print("Importazione degli articoli nel database %s, conclusa" % NOME_FILE_DB)
    #############################
    # salva e chiude il database
    #############################
    preventivo.save_database()
    preventivo.connection_shutdown()
    ###############################################
    # rimuove i file csv estratti
    ###############################################
    for filename in filename_list:
        if os.path.isfile(filename):
            print "Eliminazione dei file csv: %s" % filename
            os.remove(filename)
    return True

################################################################################
# Conversione listino FINPOLO in listino METEL
################################################################################
def TranslateFinpoloFile(input_filename, output_filename=None):
    """Conversione listino FINPOLO in listino METEL"""
    def convert_PrezzoRivenditore(txt):
        try:
            stringa = "{0}".format(int(round((float(txt)*100), 2)))
        except ValueError:
            stringa = "0"*11
        if len(stringa) < 11:
            stringa = "0" * (11-len(stringa)) + stringa
        return stringa[-11:]
    # inizializzo la lista degli articoli convertiti
    lista_articoli_metel = list()
    date = "{0:%Y%m%d}".format(datetime.datetime.now())
    if output_filename is None:
        output_filename = input_filename + '_new.txt'
    with open(input_filename) as flist:
        print ("METEL Conversion started from filename: {0}".format(input_filename))
        article_list = flist.readlines()
        for stringa in article_list:
            #stringa = unicode(stringa, 'iso-8859-15')
            SiglaMarchio = stringa[0:3]
            CodiceProdAzienda = stringa[4:20]
            CodiceEAN =  stringa[-15:].strip('\r\n')
            DescrizioneProdotto = stringa[24:67]
            QuantitaCartone = "00001"
            QuantitaMulOrdinazione = "00001"
            QuantitaMinOrdinazione = "00001"
            QuantitaMaxOrdinazione = "999999"
            LeadTime = "D"
            PrezzoRivenditore = convert_PrezzoRivenditore(stringa[101:112])
            PrezzoPubblico = PrezzoRivenditore
            MoltiplicatorePrezzo = stringa[113:119]
            CodiceValuta = "EUR"
            UnitaMisura = stringa[94:97]
            ProdottoComposto = "0"
            StatoProdotto = "1"
            DataUltimaVariazione = date
            FamigliaSconto = ' '*18 #campo opzionale
            FamigliaStatistica = ' '*18 #campo opzionale
            # creo il campo articolo e lo aggiungo alla lista
            articolo = "{0}{1}{2}{3}{4}{5}{6}{7}{8}{9}{10}{11}{12}{13}{14}{15}{16}{17}{18}\r\n".format(
                       SiglaMarchio, CodiceProdAzienda, CodiceEAN, 
                       DescrizioneProdotto, QuantitaCartone, 
                       QuantitaMulOrdinazione, QuantitaMinOrdinazione,
                       QuantitaMaxOrdinazione, LeadTime, 
                       PrezzoRivenditore, PrezzoPubblico, MoltiplicatorePrezzo, 
                       CodiceValuta, UnitaMisura, ProdottoComposto, StatoProdotto,
                       DataUltimaVariazione, FamigliaSconto, FamigliaStatistica)
            lista_articoli_metel.append(articolo)
    with open(output_filename, 'w') as fmetel:
        fmetel.writelines(lista_articoli_metel)
    print ("METEL Conversion is over, new METEL filename: {0}".format(output_filename))
    return
    
################################################################################
# Funzioni per conversioni di stringhe in valori interi o a virgola mobile
################################################################################
def __floatconvert (string):
    if string == str():
        return float(0)
    elif type(string) == str:
        try:
            return float(string)
        except ValueError:
            return 0.0
    else:
        return 0.0


def __intconvert (string):
    if string == str():
        return int(0)
    elif type(string) == str:
        try:
            return int(string)
        except ValueError:
            return 0
    else:
        return 0

####################################################
# Esecuzione del programma (da linea di comando)
####################################################
if __name__ == '__main__':
    # estrae le tavole dal file .mdb
    DATABASE = sys.argv[1]
    # esegue l'importazione del file usando la libreria preventa-lib.py
    FILE_ARCHIVIO = DATABASE.replace(".", "_") + ".db"
    #dump_mdb(DATABASE)
    #import_archivio(DATABASE, FILE_ARCHIVIO)
    import_preventivo(DATABASE, FILE_ARCHIVIO)
